@@ -1,10 +1,12 @@
 
 # messages
 msg_no_output = "When outpath not indicated, it will use inputpath as default.\
-                 \nPlease Type [Y]es/[N]o/[Outpath](Default Yes):\n"
+                 \nPlease Type [Y]es/[N]o/[Outpath]/[P]rint(Default Yes):\n"
 msg_passwd = "enter pasword: "
 msg_file_not_found = "file doesn't exist."
 
 # symbols
 yes_symbols = ['y','Y']
-no_symbols = ['n','N']
\ No newline at end of file
+no_symbols = ['n','N']
+print_symbols = ['p','P']
+int_symbols = ['i','I']
\ No newline at end of file
